============
Contributing
============

We're thrilled that you're interested in contributing to the BO4E (Business Object for Energy) project.
This is an open-source project and we love to see new contributors.

Our project has already benefited from the contributions of amazing developers.
We're excited to see your name join this list!

Whether you're fixing bugs, adding new features, or improving documentation, your work will make a significant impact.

Please make sure to read our [Contributing Guide](LINK_TO_CONTRIBUTING_GUIDE) and feel free to reach out if you have any questions or need help.
Just open an issue or send us an email.
We can also provide you with an invitation link to our Slack workspace.

Thank you for your interest in BO4E, and we look forward to seeing your contributions!

Contributors
------------

The following people have contributed to the development of this project:

* Kevin Krechan <kevin.krechan@hochfrequenz.de>
* Leon Haffmans <leon.haffmans@hochfrequenz.de>
* Annika Schlögl <annika.schloegl@hochfrequenz.de>
* Franziska Vesely <franziska.vesely@hochfrequenz.de>
* Konstantin Klein <konstantin.klein@hochfrequenz.de>
* Tim Steufmehl <tim.steufmehl@enet.eu>
* Kevin Frenken <kevin.frenken@enet.eu>
